@@ -1,7 +1,7 @@
 import unittest
 import numpy as np
 import pandas as pd
-from sklearn.linear_model import LinearRegression
+from sklearn.linear_model import LogisticRegression
 
 from bcselector.variable_selection import DiffVariableSelector, FractionVariableSelector, NoCostVariableSelector
 from bcselector.data_generation import MatrixGenerator, DataFrameGenerator
@@ -9,12 +9,13 @@ from bcselector.data_generation import MatrixGenerator, DataFrameGenerator
 class TestMatrixGenerator(unittest.TestCase):
     def test_cife(self):
         # Given
-        n_cols = 50
-        n_rows = 100
+        n_cols = 20
+        n_rows = 1000
+        model = LogisticRegression()
 
         # When
         mg = MatrixGenerator()
-        X, y, costs = mg.generate(n_rows=n_rows, n_cols=n_cols, seed=0)
+        X, y, costs = mg.generate(n_rows=n_rows, n_cols=n_cols, seed=2)
         lamb = 1
         beta = 0.5
 
@@ -25,6 +26,8 @@ class TestMatrixGenerator(unittest.TestCase):
                 lamb=lamb,
                 j_criterion_func='cife',
                 beta=beta)
+        dvs.scoreCV(model=model, cv = 5)
+        dvs.plot_scores(compare_no_cost_method=True, model=model)
 
         self.assertIsInstance(dvs.variables_selected_order, list)
         self.assertEqual(len(dvs.variables_selected_order), len(costs))
